==> plasma_2.0.0.tar.gz: plasma_2.0.0/core_blas/core_zgelqt.f <==
      SUBROUTINE CORE_ZGELQT( M, N, IB, A, LDA, T, LDT,
     $                       TAU, WORK, INFO )

*********************************************************************
*     PLASMA core_blas routine (version 2.0.0)                      *
*     Release Date: July, 4th 2009                                  *
*     PLASMA is a software package provided by Univ. of Tennessee,  *
*     Univ. of California Berkeley and Univ. of Colorado Denver.    *
*********************************************************************
*
*     .. Scalar Arguments ..
      INTEGER            M, N, IB, LDA, LDT, INFO
*     ..
*     .. Array Arguments ..
      COMPLEX*16            A( LDA, * ), T( LDT, * )
      COMPLEX*16            TAU( * ), WORK( * )
*     ..
*
*  Purpose
*  =======
*
*  CORE_ZGELQT computes a LQ factorization of a complex M-by-N tile A:
*  A = L * Q.
*
*  Arguments
*  =========
*
*  M       (input) INTEGER
*          The number of rows of the tile A.  M >= 0.
*
*  N       (input) INTEGER
*          The number of columns of the tile A.  N >= 0.
*
*  IB      (input) INTEGER
*          The inner-blocking size.  IB >= 0.
*
*  A       (input/output) COMPLEX*16 array, dimension (LDA,N)
*          On entry, the M-by-N tile A.
*          On exit, the elements on and below the diagonal of the array
*          contain the M-by-min(M,N) lower trapezoidal tile L (L is
*          lower triangular if M <= N); the elements above the diagonal,
*          with the array TAU, represent the unitary tile Q as a
*          product of elementary reflectors (see Further Details).
*
*  LDA     (input) INTEGER
*          The leading dimension of the array A.  LDA >= max(1,M).
*
*  T       (output) COMPLEX*16 array, dimension (LDT,N)
*          The IB-by-N triangular factor T of the block reflector.
*          T is upper triangular by block (economic storage);
*          The rest of the array is not referenced.
*
*  LDT     (input) INTEGER
*          The leading dimension of the array T. LDT >= IB.
*
*  TAU     (output) COMPLEX*16 array, dimension (min(M,N))
*          The scalar factors of the elementary reflectors (see Further
*          Details).
*
*  WORK    (workspace) COMPLEX*16 array, dimension (M)
*
*  INFO    (output) INTEGER
*          = 0:  successful exit
*          < 0:  if INFO = -i, the i-th argument had an illegal value
*
*  Further Details
*  ===============
*
*  The tile Q is represented as a product of elementary reflectors
*
*     Q = H(k)' . . . H(2)' H(1)', where k = min(M,N).
*
*  Each H(i) has the form
*
*     H(i) = I - tau * v * v'
*
*  where tau is a complex scalar, and v is a complex vector with
*  v(1:i-1) = 0 and v(i) = 1; conjg(v(i+1:n)) is stored on exit in
*  A(i,i+1:n), and tau in TAU(i).
*
*  =====================================================================
*
*     .. Local Scalars ..
      INTEGER            I, K, SB, IINFO
*     ..
*     .. External Subroutines ..
      EXTERNAL           XERBLA, ZGELQ2, ZLARFT, CORE_ZUNMLQ
*     ..
*     .. Intrinsic Functions ..
      INTRINSIC          MAX, MIN
*     ..
*     Test the input arguments
      INFO = 0
      IF( M.LT.0 ) THEN
         INFO = -1
      ELSE IF( N.LT.0 ) THEN
         INFO = -2
      ELSE IF( IB.LT.0 ) THEN
         INFO = -3
      ELSE IF( LDA.LT.MAX( 1, M ) ) THEN
         INFO = -5
      ELSE IF( LDT.LT.MAX( 1, IB ) ) THEN
         INFO = -7
      END IF
      IF( INFO.NE.0 ) THEN
         CALL XERBLA( 'CORE_ZGELQT', -INFO )
         RETURN
      END IF
*
*     Quick return if possible.
*
      IF( M.EQ.0 .OR. N.EQ.0 .OR. IB.EQ.0 )
     $   RETURN
*
      K = MIN( M, N )
*
      DO 10 I = 1, K, IB
         SB = MIN( IB, K-I+1 )
         CALL ZGELQ2( SB, N-I+1, A( I, I ), LDA, TAU( I ), WORK, IINFO )
*
         CALL ZLARFT( 'Forward', 'Rowwise', N-I+1, SB,
     $                A( I, I ),LDA, TAU( I ),
     $                T( 1, I ), LDT )
*
         IF ( M.GT.( I+IB-1 ) ) THEN   
             CALL CORE_ZUNMLQ( 'Right', 'ConjTranspose',
     $                        M-I+1-SB, N-I+1, SB, SB,
     $                        A( I, I ), LDA,
     $                        T( 1, I ), LDT,
     $                        A( I+SB, I ), LDA,
     $                        WORK, M-I+1-SB, IINFO )
         ENDIF
 10   CONTINUE
*
      RETURN
*
*     End of CORE_ZGELQT.
*
      END

==> plasma_2.1.0.tar.gz: plasma_2.1.0/core_blas/core_zgelqt.f <==
      SUBROUTINE CORE_ZGELQT( M, N, IB, A, LDA, T, LDT,
     $                       TAU, WORK, INFO )

*********************************************************************
*     PLASMA core_blas routine (version 2.1.0)                      *
*     Author: Hatem Ltaief                                          *
*     Release Date: November, 15th 2009                             *
*     PLASMA is a software package provided by Univ. of Tennessee,  *
*     Univ. of California Berkeley and Univ. of Colorado Denver.    *
*********************************************************************
*
*     .. Scalar Arguments ..
      INTEGER            M, N, IB, LDA, LDT, INFO
*     ..
*     .. Array Arguments ..
      COMPLEX*16            A( LDA, * ), T( LDT, * )
      COMPLEX*16            TAU( * ), WORK( * )
*     ..
*
*  Purpose
*  =======
*
*  CORE_ZGELQT computes a LQ factorization of a complex M-by-N tile A:
*  A = L * Q.
*
*  Arguments
*  =========
*
*  M       (input) INTEGER
*          The number of rows of the tile A.  M >= 0.
*
*  N       (input) INTEGER
*          The number of columns of the tile A.  N >= 0.
*
*  IB      (input) INTEGER
*          The inner-blocking size.  IB >= 0.
*
*  A       (input/output) COMPLEX*16 array, dimension (LDA,N)
*          On entry, the M-by-N tile A.
*          On exit, the elements on and below the diagonal of the array
*          contain the M-by-min(M,N) lower trapezoidal tile L (L is
*          lower triangular if M <= N); the elements above the diagonal,
*          with the array TAU, represent the unitary tile Q as a
*          product of elementary reflectors (see Further Details).
*
*  LDA     (input) INTEGER
*          The leading dimension of the array A.  LDA >= max(1,M).
*
*  T       (output) COMPLEX*16 array, dimension (LDT,N)
*          The IB-by-N triangular factor T of the block reflector.
*          T is upper triangular by block (economic storage);
*          The rest of the array is not referenced.
*
*  LDT     (input) INTEGER
*          The leading dimension of the array T. LDT >= IB.
*
*  TAU     (output) COMPLEX*16 array, dimension (min(M,N))
*          The scalar factors of the elementary reflectors (see Further
*          Details).
*
*  WORK    (workspace) COMPLEX*16 array, dimension (M)
*
*  INFO    (output) INTEGER
*          = 0:  successful exit
*          < 0:  if INFO = -i, the i-th argument had an illegal value
*
*  Further Details
*  ===============
*
*  The tile Q is represented as a product of elementary reflectors
*
*     Q = H(k)' . . . H(2)' H(1)', where k = min(M,N).
*
*  Each H(i) has the form
*
*     H(i) = I - tau * v * v'
*
*  where tau is a complex scalar, and v is a complex vector with
*  v(1:i-1) = 0 and v(i) = 1; conjg(v(i+1:n)) is stored on exit in
*  A(i,i+1:n), and tau in TAU(i).
*
*  =====================================================================
*
*     .. Local Scalars ..
      INTEGER            I, K, SB, IINFO
*     ..
*     .. External Subroutines ..
      EXTERNAL           XERBLA, ZGELQ2, ZLARFT, CORE_ZUNMLQ
*     ..
*     .. Intrinsic Functions ..
      INTRINSIC          MAX, MIN
*     ..
*     Test the input arguments
      INFO = 0
      IF( M.LT.0 ) THEN
         INFO = -1
      ELSE IF( N.LT.0 ) THEN
         INFO = -2
      ELSE IF( IB.LT.0 ) THEN
         INFO = -3
      ELSE IF( LDA.LT.MAX( 1, M ) ) THEN
         INFO = -5
      ELSE IF( LDT.LT.MAX( 1, IB ) ) THEN
         INFO = -7
      END IF
      IF( INFO.NE.0 ) THEN
         CALL XERBLA( 'CORE_ZGELQT', -INFO )
         RETURN
      END IF
*
*     Quick return if possible.
*
      IF( M.EQ.0 .OR. N.EQ.0 .OR. IB.EQ.0 )
     $   RETURN
*
      K = MIN( M, N )
*
      DO 10 I = 1, K, IB
         SB = MIN( IB, K-I+1 )
         CALL ZGELQ2( SB, N-I+1, A( I, I ), LDA, TAU( I ), WORK, IINFO )
*
         CALL ZLARFT( 'Forward', 'Rowwise', N-I+1, SB,
     $                A( I, I ),LDA, TAU( I ),
     $                T( 1, I ), LDT )
*
         IF ( M.GT.( I+IB-1 ) ) THEN   
             CALL CORE_ZUNMLQ( 'Right', 'ConjTranspose',
     $                        M-I+1-SB, N-I+1, SB, SB,
     $                        A( I, I ), LDA,
     $                        T( 1, I ), LDT,
     $                        A( I+SB, I ), LDA,
     $                        WORK, M-I+1-SB, IINFO )
         ENDIF
 10   CONTINUE
*
      RETURN
*
*     End of CORE_ZGELQT.
*
      END
